@@ -205,7 +205,7 @@ class DeprecatedCommand(KickstartCommand):
 
     def dataList(self):
         """Override the method of the deprecated command."""
-        return None
+        return []
 
     @property
     def dataClass(self):
@@ -238,7 +238,7 @@ class RemovedCommand(KickstartCommand):
 
     def dataList(self):
         """Override the method of the removed command."""
-        return None
+        return []
 
     @property
     def dataClass(self):
@@ -485,6 +485,7 @@ class BaseHandler(KickstartHandler):
 
            Instance attributes:
 
+           certificates -- A list of pykickstart.parser.Certificate instances
            packages -- An instance of pykickstart.parser.Packages which
                        describes the packages section of the input file.
            platform -- A string describing the hardware platform, which is
@@ -503,6 +504,7 @@ class BaseHandler(KickstartHandler):
 
         # This isn't really a good place for these, but it's better than
         # everything else I can think of.
+        self.certificates = []
         self.scripts = []
         self.packages = Packages()
         self.platform = ""
@@ -537,6 +539,9 @@ class BaseHandler(KickstartHandler):
 
         retval += self.packages.__str__()
 
+        for cert in self.certificates:
+            retval += cert.__str__()
+
         return retval
 
     def _registerCommands(self, mapping=None, dataMapping=None, commandUpdates=None,
