@@ -18,8 +18,8 @@
 # with the express permission of Red Hat, Inc.
 #
 from textwrap import dedent
-from pykickstart.version import versionToLongString
-from pykickstart.version import FC6, F8, F11, F13, F14, F15, F21, F27, F30
+from pykickstart.version import versionToLongString, F40
+from pykickstart.version import FC6, F8, F11, F13, F14, F15, F21, F27, F30, F33
 from pykickstart.base import BaseData, KickstartCommand
 from pykickstart.errors import KickstartError, KickstartParseError, KickstartParseWarning
 from pykickstart.options import KSOptionParser, commaSplit, ksboolean
@@ -195,6 +195,9 @@ class F30_RepoData(F27_RepoData):
 class RHEL7_RepoData(F21_RepoData):
     pass
 
+class RHEL8_RepoData(F30_RepoData):
+    pass
+
 class FC6_Repo(KickstartCommand):
     removedKeywords = KickstartCommand.removedKeywords
     removedAttrs = KickstartCommand.removedAttrs
@@ -321,15 +324,17 @@ class F8_Repo(FC6_Repo):
                         """)
         op.add_argument("--excludepkgs", type=commaSplit, version=F8, help="""
                         A comma-separated list of package names and globs that
-                        must not be pulled from this repository. This is useful
+                        must not be fetched from this repository. This is useful
                         if multiple repositories provide the same package and
-                        you want to make sure it comes from a particular
-                        repository.""")
+                        you want to make sure it is not fetched from a particular
+                        repository during installation.""")
         op.add_argument("--includepkgs", type=commaSplit, version=F8, help="""
                         A comma-separated list of package names and globs that
-                        must be pulled from this repository. This is useful if
-                        multiple repositories provide the same package and you
-                        want to make sure it comes from this repository.""")
+                        can be pulled from this repository. Any other packages
+                        provided by the repository not on this list will be ignored.
+                        This is useful if you want to install just a single package
+                        or set of packages from a repository while including all
+                        other packages the repository provides.""")
         return op
 
     def methodToRepo(self):
@@ -455,14 +460,47 @@ class F30_Repo(F27_Repo):
         op = F27_Repo._getParser(self)
         op.add_argument("--sslcacert", version=F30, help="""
                         Path to the file holding one or more SSL certificates
-                        to verify the repository host with.""")
+                        to verify the repository host with.
+
+                        **Note** Usage of this parameter is discouraged. It is
+                        designed for a specific image building tool use and
+                        there are plans for a replacement.""")
         op.add_argument("--sslclientcert", version=F30, help="""
                         Path to the SSL client certificate (PEM file) which
-                        should be used to connect to the repository.""")
+                        should be used to connect to the repository.
+
+                        **Note** Usage of this parameter is discouraged. It is
+                        designed for a specific image building tool use and
+                        there are plans for a replacement.""")
         op.add_argument("--sslclientkey", version=F30, help="""
                         Path to the private key file associated with the client
-                        certificate given with --sslclientcert.""")
+                        certificate given with --sslclientcert.
+
+                        **Note** Usage of this parameter is discouraged. It is
+                        designed for a specific image building tool use and
+                        there are plans for a replacement.""")
+        return op
+
+class F33_Repo(F30_Repo):
+    removedKeywords = F30_Repo.removedKeywords
+    removedAttrs = F30_Repo.removedAttrs
+
+    def _getParser(self):
+        op = F30_Repo._getParser(self)
+        op.add_argument("--ignoregroups", type=ksboolean, deprecated=F33)
         return op
 
 class RHEL7_Repo(F21_Repo):
     pass
+
+class RHEL8_Repo(F30_Repo):
+    pass
+
+class F40_Repo(F33_Repo):
+    removedKeywords = F33_Repo.removedKeywords + ["ignoregroups"]
+    removedAttrs = F33_Repo.removedAttrs + ["ignoregroups"]
+
+    def _getParser(self):
+        op = F33_Repo._getParser(self)
+        op.remove_argument("--ignoregroups", version=F40)
+        return op
