@@ -18,7 +18,8 @@
 # with the express permission of Red Hat, Inc.
 #
 import warnings
-from pykickstart.version import FC3, FC6, F18
+from pykickstart.version import FC3, FC6, F18, F40
+from pykickstart.version import RHEL10
 from pykickstart.base import KickstartCommand
 from pykickstart.errors import KickstartParseError, KickstartDeprecationWarning
 from pykickstart.options import KSOptionParser, commaSplit
@@ -328,7 +329,7 @@ class F25_Timezone(F23_Timezone):
                         This is optional but at least one of the options needs
                         to be used if no timezone is specified.
                         """)
-        op.add_argument("--utc", "--isUtc", dest="isUtc", action="store_true",
+        op.add_argument("--utc", dest="isUtc", action="store_true",
                         default=False, version=FC6, help="""
                         If present, the system assumes the hardware clock is set
                         to UTC (Greenwich Mean) time.
@@ -339,6 +340,10 @@ class F25_Timezone(F23_Timezone):
                         look at this list:
                         http://vpodzime.fedorapeople.org/timezones_list.txt*
                         """)
+        op.add_argument("--isUtc", dest="isUtc", action="store_true",
+                        default=False, version=FC6, help="""
+                        This is an alias for the ``--utc`` option.
+                        """)
         op.add_argument("--nontp", action="store_true", default=False,
                         version=F18, help="""
                         Disable automatic starting of NTP service.
@@ -443,3 +448,78 @@ class F33_Timezone(F32_Timezone):
                             "timesource --ntp-disable command invocation."),
                           KickstartDeprecationWarning)
         return self
+
+
+class F40_Timezone(F33_Timezone):
+
+    def _getParser(self):
+        op = super()._getParser()
+
+        # Deprecate options.
+        op.add_argument("--isUtc", dest="isUtc", action="store_true",
+                        default=False, deprecated=F40)
+        op.add_argument("--nontp", action="store_true", default=False,
+                        deprecated=F40)
+        op.add_argument("--ntpservers", dest="ntpservers", type=commaSplit,
+                        metavar="<server1>,<server2>,...,<serverN>",
+                        deprecated=F40)
+
+        return op
+
+    def parse(self, args):
+        # Skip future deprecation warnings.
+        return F25_Timezone.parse(self, args)
+
+# This is based on timezone before the deprecations and warnings
+class RHEL10_Timezone(F32_Timezone):
+    removedKeywords = F32_Timezone.removedKeywords + ["nontp", "ntpservers"]
+    removedAttrs = F32_Timezone.removedAttrs + ["nontp", "ntpservers"]
+
+    def __init__(self, writePriority=0, *args, **kwargs):
+        F32_Timezone.__init__(self, writePriority, *args, **kwargs)
+        self.op = self._getParser()
+        self.deleteRemovedAttrs()
+
+    def _getParser(self):
+        op = F32_Timezone._getParser(self)
+        op.remove_argument("--nontp", version=RHEL10)
+        op.remove_argument("--ntpservers", version=RHEL10)
+        op.remove_argument("--isUtc", version=RHEL10)
+        return op
+
+    def _getArgsAsStr(self):
+        retval = ""
+
+        if self.timezone:
+            retval += " " + self.timezone
+
+        if self.isUtc:
+            retval += " --utc"
+
+        return retval
+
+    # override parse to remove the self.nontp and self.ntpservers checks
+    def parse(self, args):
+        ns = self.op.parse_args(args=args, lineno=self.lineno)
+        self.set_to_self(ns)
+
+        # just "timezone" without any arguments and timezone specification doesn't really make sense,
+        # so throw an error when we see it (it might even be an indication of an incorrect machine generated kickstart)
+        if not args:
+            error_message = _("At least one option and/or an argument are expected for the %s command") % "timezone"
+            raise KickstartParseError(error_message, lineno=self.lineno)
+
+        # To be able to support the timezone command being used without
+        # a timezone specification:
+        # - we don't call the parse() method of the ancestors
+        # -> due to the FC3 parse() method that would be eventually called,
+        #    which throws an exception if no timezone specification is provided
+        # - we implement the relevant functionality of the ancestor methods here
+
+        if len(ns.timezone) == 1:
+            self.timezone = ns.timezone[0]
+        elif len(ns.timezone) > 1:
+            error_message = _("One or zero arguments are expected for the %s command") % "timezone"
+            raise KickstartParseError(error_message, lineno=self.lineno)
+
+        return self
