@@ -98,6 +98,9 @@ class RHEL8_VolGroupData(F21_VolGroupData):
 class RHEL9_VolGroupData(F21_VolGroupData):
     pass
 
+class RHEL10_VolGroupData(F21_VolGroupData):
+    pass
+
 class FC3_VolGroup(KickstartCommand):
     removedKeywords = KickstartCommand.removedKeywords
     removedAttrs = KickstartCommand.removedAttrs
@@ -235,3 +238,6 @@ class RHEL8_VolGroup(F21_VolGroup):
 
 class RHEL9_VolGroup(F21_VolGroup):
     pass
+
+class RHEL10_VolGroup(F21_VolGroup):
+    pass
