@@ -36,8 +36,8 @@ from pykickstart.constants import KS_SCRIPT_PRE, KS_SCRIPT_POST, KS_SCRIPT_TRACE
                                   KS_BROKEN_IGNORE, KS_BROKEN_REPORT
 from pykickstart.errors import KickstartParseError, KickstartDeprecationWarning
 from pykickstart.options import KSOptionParser
-from pykickstart.version import FC4, F7, F9, F18, F21, F22, F24, F32, F34, RHEL6, RHEL7, RHEL9, \
-    isRHEL
+from pykickstart.version import FC4, F7, F9, F18, F21, F22, F24, F32, F34, F40, F42
+from pykickstart.version import isRHEL, RHEL6, RHEL7, RHEL9, RHEL10
 from pykickstart.i18n import _
 
 class Section(object):
@@ -226,8 +226,7 @@ class PreScriptSection(ScriptSection):
     _description = """
         You can add commands to run on the system immediately after the ks.cfg
         has been parsed and the lang, keyboard, and url options have been
-        processed. This section must be at the end of the kickstart file (after
-        the commands) and must start with the %pre command. You can access the
+        processed. This section must start with the %pre command. You can access the
         network in the %pre section; however, name service has not been
         configured at this point, so only IP addresses will work.
 
@@ -315,10 +314,9 @@ class PostScriptSection(ScriptSection):
     _title = "Post-installation Script"
     _description="""
     You have the option of adding commands to run on the system once the
-    installation is complete. This section must be at the end of the
-    kickstart file and must start with the %post command. This section is
-    useful for functions such as installing additional software and
-    configuring an additional nameserver.
+    installation is complete. This section must start with the %post command.
+    This section is useful for functions such as installing additional software
+    and configuring an additional nameserver.
 
     You may have more than one %post section, which can be useful for cases
     where some post-installation scripts need to be run in the chroot and
@@ -404,6 +402,9 @@ class OnErrorScriptSection(ScriptSection):
     all %onerror scripts will be run and then all %traceback scripts will be run
     afterwards.
 
+    To force %onerror execution for any error (not just fatal) use non interactive
+    installation (inst.cmdline in kernel command line options).
+
     Each %onerror script is required to be closed with a corresponding %end.
 
     .. note::
@@ -707,13 +708,30 @@ class PackageSection(Section):
         if self.version < F32:
             return op
 
-        op.add_argument("--instLangs", "--inst-langs", dest="instLangs", default=None,
+        op.add_argument("--instLangs", dest="instLangs", default=None,
                         version=F32, help="Added ``--inst-langs`` alias")
 
-        op.add_argument("--excludeWeakdeps", "--exclude-weakdeps", dest="excludeWeakdeps",
+        op.add_argument("--inst-langs", dest="instLangs", default=None,
+                        version=F32, help="""
+                        Specify the list of languages that should be installed.
+                        This is different from the package group level
+                        selections, though. This option does not specify what
+                        package groups should be installed. Instead, it controls
+                        which translation files from individual packages should
+                        be installed by setting RPM macros.""")
+
+        op.add_argument("--excludeWeakdeps", dest="excludeWeakdeps",
                         action="store_true", default=False, version=F32,
                         help="Added ``--exclude-weakdeps`` alias")
 
+        op.add_argument("--exclude-weakdeps", dest="excludeWeakdeps",
+                        action="store_true", default=False, version=F32,
+                        help="""
+                        Do not install packages from weak dependencies. These
+                        are packages linked to the selected package set by
+                        Recommends and Supplements flags. By default weak
+                        dependencies will be installed.""")
+
         op.add_argument("--ignorebroken", action="store_true", default=False, version=F32,
                         help="""
                         Ignore any packages, groups or modules with conflicting files.
@@ -730,6 +748,18 @@ class PackageSection(Section):
             # The --ignorebroken feature is not supported on RHEL.
             op.remove_argument("--ignorebroken", version=RHEL9)
 
+        if self.version < F40:
+            return op
+
+        op.add_argument("--instLangs", dest="instLangs", default=None, deprecated=F40)
+        op.add_argument("--excludeWeakdeps", dest="excludeWeakdeps", action="store_true",
+                        default=False, deprecated=F40)
+
+        # --instLangs and --excludeWeakdeps are removed in RHEL10 and later
+        if isRHEL(self.version) and self.version >= RHEL10:
+            op.remove_argument("--instLangs", version=RHEL10)
+            op.remove_argument("--excludeWeakdeps", version=RHEL10)
+
         return op
 
     def handleHeader(self, lineno, args):
@@ -800,12 +830,114 @@ class PackageSection(Section):
         else:
             self.handler.packages.handleBroken = KS_BROKEN_REPORT
 
-        for arg in args:
-            for option, new_option in \
-                {"--instLangs": "--inst-langs", "--excludeWeakdeps": "--exclude-weakdeps"}.items():
-                if option in arg:
-                    warnings.warn(_("The %(option)s option on line %(lineno)s will be deprecated in "
-                                    "future releases. Please modify your kickstart file to replace "
-                                    "this option with its preferred alias %(new_option)s.")
-                                  % {"option": option, "lineno": lineno, "new_option": new_option},
-                                  KickstartDeprecationWarning)
+        if self.version < F40 and self._contains_option(args, "--instLangs"):
+            self._warn_alias_future_deprecation("--instLangs", "--inst-langs", lineno)
+
+        if self.version < F40 and self._contains_option(args, "--excludeWeakdeps"):
+            self._warn_alias_future_deprecation("--excludeWeakdeps", "--exclude-weakdeps", lineno)
+
+    def _contains_option(self, arguments, option):
+        """Check if the option is used in the argument."""
+        return any(arg == option or arg.startswith(option + "=") for arg in arguments)
+
+    def _warn_alias_future_deprecation(self, option, new_option, lineno):
+        """Show a warning about a future deprecation of the specified alias."""
+        warnings.warn(_(
+            "The %(option)s option on line %(lineno)s will be deprecated in "
+            "future releases. Please modify your kickstart file to replace "
+            "this option with its preferred alias %(new_option)s."
+        ) % {"option": option, "lineno": lineno, "new_option": new_option},
+            KickstartDeprecationWarning
+        )
+
+class CertificateSection(Section):
+    sectionOpen = "%certificate"
+    _title = "Certificate"
+    allLines = True
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self._certificate = {
+            "filename": None,
+            "dir": None,
+            "cert": []
+        }
+
+    def _getParser(self):
+        op = KSOptionParser(prog=self.sectionOpen, description="""
+                            The %certificate section is used to specify certificates to be
+                            installed into the installer environment and the installed system.
+
+                            The certificate content should be in a Base64 ASCII enconding
+                            format. It will be written into a file specified by the
+                            --dir and --filename options.
+
+                            Example::
+
+                                %certificate --filename custom_certificate.pem --dir /etc/pki/dns/
+                                -----BEGIN CERTIFICATE-----
+                                MIIBjTCCATOgAwIBAgIUWR5HO3v/0I80Ne0jQWVZFODuWLEwCgYIKoZIzj0EAwIw
+                                FDESMBAGA1UEAwwJUlZURVNUIENBMB4XDTI0MTEyMDEzNTk1N1oXDTM0MTExODEz
+                                NTk1N1owFDESMBAGA1UEAwwJUlZURVNUIENBMFkwEwYHKoZIzj0CAQYIKoZIzj0D
+                                AQcDQgAELghFKGEgS8+5/2nx50W0xOqTrKc2Jz/rD/jfL0m4z4fkeAslCOkIKv74
+                                0wfBXMngxi+OF/b3Vh8FmokuNBQO5qNjMGEwHQYDVR0OBBYEFOJarl9Xkd13sLzI
+                                mHqv6aESlvuCMB8GA1UdIwQYMBaAFOJarl9Xkd13sLzImHqv6aESlvuCMA8GA1Ud
+                                EwEB/wQFMAMBAf8wDgYDVR0PAQH/BAQDAgEGMAoGCCqGSM49BAMCA0gAMEUCIAet
+                                7nyre42ReoRKoyHWLDsQmQDzoyU3FQdC0cViqOtrAiEAxYIL+XTTp7Xy9RNE4Xg7
+                                yNWXfdraC/AfMM8fqsxlVJM=
+                                -----END CERTIFICATE-----
+                                %end
+
+                            A certificate bundle can be installed as a content of a single
+                            %certificate section.
+
+                            """, version=F42)
+
+        op.add_argument("--filename", dest="filename", required=True, version=F42,
+                        help="""The name of the certificate file.""")
+
+        op.add_argument("--dir", dest="dir", required=True, version=F42, help="""
+                        The directory where the certificate should be installed.""")
+
+        return op
+
+    def handleHeader(self, lineno, args):
+        """Parse the header of the %certificate section for the arguments."""
+
+        Section.handleHeader(self, lineno, args)
+        op = self._getParser()
+
+        ns = op.parse_args(args=args[1:], lineno=lineno)
+
+        self._certificate["filename"] = ns.filename
+
+        if ns.dir:
+            self._certificate["dir"] = ns.dir
+
+    def handleLine(self, line):
+        """Collect lines between %certificate and %end."""
+        self._certificate["cert"].append(line)
+
+    def finalize(self):
+        """Create a certificate object and add it to the handler."""
+        cert = "".join(self._certificate["cert"])
+        # Remove the newline preceding %end if there is one
+        if cert and cert[-1] == '\n':
+            cert = cert[:-1]
+        if cert.strip() == "":
+            raise KickstartParseError(_("The %certificate section is empty"))
+
+        kwargs = {
+            "cert": cert,
+            "filename": self._certificate["filename"],
+            "dir": self._certificate["dir"],
+        }
+
+        if self.dataObj is not None:
+            s = self.dataObj({}, **kwargs)
+            self._certificate = {
+                "cert": [],
+                "filename": None,
+                "dir": None,
+            }
+            self.handler.certificates.append(s)
