@@ -99,9 +99,18 @@ F36 = 36000
 F37 = 37000
 F38 = 38000
 F39 = 39000
+F40 = 40000
+RHEL10 = 40100
+F41 = 41000
+F42 = 42000
+F43 = 43000
 
 # This always points at the latest version and is the default.
-DEVEL = F39
+DEVEL = F43
+
+# On Fedora this points to DEVEL
+# On RHEL it points to the RHEL version that should be the default when no version is passed
+DEFAULT_VERSION = DEVEL
 
 # A one-to-one mapping from string representations to version numbers.
 versionMap = {
@@ -113,9 +122,9 @@ versionMap = {
     "F24": F24, "F25": F25, "F26": F26, "F27": F27, "F28": F28,
     "F29": F29, "F30": F30, "F31": F31, "F32": F32, "F33": F33,
     "F34": F34, "F35": F35, "F36": F36, "F37": F37, "F38": F38,
-    "F39": F39,
+    "F39": F39, "F40": F40, "F41": F41, "F42": F42, "F43": F43,
     "RHEL3": RHEL3, "RHEL4": RHEL4, "RHEL5": RHEL5, "RHEL6": RHEL6,
-    "RHEL7": RHEL7, "RHEL8": RHEL8, "RHEL9": RHEL9
+    "RHEL7": RHEL7, "RHEL8": RHEL8, "RHEL9": RHEL9, "RHEL10": RHEL10,
 }
 
 def stringToVersion(s):
@@ -178,9 +187,10 @@ def versionToLongString(version):
 
 def versionFromFile(f):
     """Given a file or URL, look for a line starting with #version= and
-       return the version number.  If no version is found, return DEVEL.
+       return the version number.  If no version is found, return the
+       default version (DEVEL on Fedora and RHELx on RHEL).
     """
-    v = DEVEL
+    v = DEFAULT_VERSION
 
     contents = load_to_str(f)
 
@@ -194,7 +204,7 @@ def versionFromFile(f):
 
     return v
 
-def returnClassForVersion(version=DEVEL):
+def returnClassForVersion(version=DEFAULT_VERSION):
     """Return the class of the syntax handler for version.  version can be
        either a string or the matching constant.  Raises KickstartVersionError
        if version does not match anything.
@@ -219,7 +229,7 @@ def returnClassForVersion(version=DEVEL):
     except:
         raise KickstartVersionError(_("Unsupported version specified: %s") % version)
 
-def makeVersion(version=DEVEL):
+def makeVersion(version=DEFAULT_VERSION):
     """Return a new instance of the syntax handler for version.  version can be
        either a string or the matching constant.  This function is useful for
        standalone programs which just need to handle a specific version of
