@@ -165,7 +165,7 @@ class F17_TestCase(F16_TestCase):
         self.assert_parse("autopart --type=lvm",
                           "autopart --type=lvm\n")
 
-        if self.__class__.__name__ != "RHEL8_TestCase":
+        if self.__class__.__name__ not in ["RHEL8_TestCase", "RHEL10_TestCase"]:
             self.assert_parse("autopart --type=btrfs",
                               "autopart --type=btrfs\n")
 
@@ -355,5 +355,18 @@ class F38_TestCase(F29_TestCase):
                           "autopart --hibernation\n")
         self.assert_parse_error("autopart --hibernation --noswap")
 
+class RHEL10_TestCase(F38_TestCase):
+    def runTest(self):
+        F38_TestCase.runTest(self)
+        self.assert_parse_error("autopart --type=btrfs")
+
+class F41_TestCase(F38_TestCase):
+    def runTest(self):
+        F38_TestCase.runTest(self)
+        self.assert_parse("autopart --encrypted --passphrase=\"test\" --luks-version=luks2-hw-opal --hw-passphrase=\"testhw\"",
+                          "autopart --encrypted --passphrase=\"test\" --luks-version=luks2-hw-opal --hw-passphrase=\"testhw\"\n")
+        self.assert_parse_error("autopart --passphrase=\"test\" --hw-passphrase=\"testhw\"")
+        self.assert_parse_error("autopart --encrypted --passphrase=\"test\" --luks-version=luks1 --hw-passphrase=\"testhw\"")
+
 if __name__ == "__main__":
     unittest.main()
