@@ -21,7 +21,7 @@
 import unittest
 from tests.baseclass import CommandTest, CommandSequenceTest
 
-from pykickstart.errors import KickstartError, KickstartParseWarning
+from pykickstart.errors import KickstartError, KickstartParseWarning, KickstartDeprecationWarning
 from pykickstart.version import FC6
 
 class FC6_TestCase(CommandTest):
@@ -114,6 +114,9 @@ class F11_TestCase(F8_TestCase):
         # run F8 test case
         F8_TestCase.runTest(self, urlRequired=urlRequired)
 
+        if "--ignoregroups" not in self.optionList:
+            return
+
         # pass
         for val in ("1", "true", "on"):
             self.assert_parse("repo --name=blah --baseurl=www.domain.com --cost=10 --excludepkgs=pkg1,pkg2 --includepkgs=pkg3,pkg4 --ignoregroups=%s" % val,
@@ -193,5 +196,19 @@ class F30_TestCase(F27_TestCase):
         self.assert_parse_error("repo --name=test --sslclientkey")
         self.assert_parse_error("repo --name=test --sslcacert")
 
+class F33_TestCase(F30_TestCase):
+    def runTest(self, urlRequired=False):
+        F30_TestCase.runTest(self, urlRequired=urlRequired)
+
+        self.assert_deprecated("repo", "--ignoregroups")
+        with self.assertWarns(KickstartDeprecationWarning):
+            self.assert_parse("repo --name=blah --baseurl=www.domain.com --ignoregroups=true")
+
+class F40_TestCase(F30_TestCase):
+    def runTest(self, urlRequired=False):
+        F30_TestCase.runTest(self, urlRequired=urlRequired)
+        self.assert_removed("repo", "--ignoregroups")
+
+
 if __name__ == "__main__":
     unittest.main()
