@@ -19,7 +19,7 @@
 #
 import unittest
 from tests.baseclass import CommandTest
-from pykickstart.errors import KickstartParseError
+from pykickstart.errors import KickstartParseError, KickstartDeprecationWarning
 from pykickstart.commands.timezone import FC3_Timezone, FC6_Timezone, F18_Timezone, F25_Timezone, RHEL7_Timezone
 
 
@@ -138,10 +138,12 @@ class F25_TestCase(F23_TestCase):
     def runTest(self):
         # since RHEL7 command version the timezone command can be used
         # without a timezone specification
-        self.assert_parse("timezone --utc")
-        self.assert_parse("timezone --isUtc")
-        self.assert_parse("timezone --ntpservers=ntp.cesnet.cz")
-        self.assert_parse("timezone --ntpservers=ntp.cesnet.cz,tik.nic.cz")
+        self.assert_parse("timezone --utc", "timezone --isUtc\n")
+        self.assert_parse("timezone --isUtc", "timezone --isUtc\n")
+        self.assert_parse("timezone --ntpservers=ntp.cesnet.cz", "timezone --ntpservers=ntp.cesnet.cz\n")
+        self.assert_parse("timezone --ntpservers=ntp.cesnet.cz,tik.nic.cz", "timezone --ntpservers=ntp.cesnet.cz,tik.nic.cz\n")
+        # normal usage
+        self.assert_parse("timezone Europe/Oslo --nontp", "timezone Europe/Oslo --nontp\n")
         # unknown argument
         self.assert_parse_error("timezone --blah")
         # more than two timezone specs
@@ -154,5 +156,86 @@ class F25_TestCase(F23_TestCase):
         self.assert_parse_error("timezone Europe/Sofia --nontp --ntpservers=0.fedora.pool.ntp.org,1.fedora.pool.ntp.org")
 
 
+class F32_TestCase(F25_TestCase):
+    command = "timezone"
+
+    def failures(self):
+        # Failures
+        # unknown argument
+        self.assert_parse_error("timezone --blah")
+        # more than two timezone specs
+        self.assert_parse_error("timezone foo bar", KickstartParseError, 'One or zero arguments are expected for the timezone command')
+        self.assert_parse_error("timezone --utc foo bar", exception=KickstartParseError)
+        # no options
+        self.assert_parse_error("timezone", KickstartParseError, 'At least one option and/or an argument are expected for the timezone command')
+        # contradictory options
+        self.assert_parse_error("timezone Europe/Sofia --nontp --ntpservers=0.fedora.pool.ntp.org,1.fedora.pool.ntp.org")
+
+    def runTest(self):
+        self.failures()
+
+        # Successes
+        # normal contents
+        self.assert_parse("timezone Europe/Prague --ntpservers=ntp.cesnet.cz",
+                          "timezone Europe/Prague --ntpservers=ntp.cesnet.cz\n")
+        # no timezone spec
+        self.assert_parse("timezone --ntpservers=ntp.cesnet.cz",
+                          "timezone --ntpservers=ntp.cesnet.cz\n")
+        # no ntp wanted
+        self.assert_parse("timezone Europe/Oslo --nontp",
+                          "timezone Europe/Oslo --nontp\n")
+
+        # New in F32: any variant of UTC should be returned as --utc (again - was in FC3)
+        # --utc should result in no warnings
+        self.assert_parse("timezone --utc Europe/Bratislava",
+                          "timezone Europe/Bratislava --utc\n")
+        # but --isUtc should now give warning
+        with self.assertWarns(KickstartDeprecationWarning):
+            self.assert_parse("timezone --isUtc Europe/Bratislava")
+
+
+class F33_TestCase(F32_TestCase):
+    command = "timezone"
+
+    def runTest(self):
+        F32_TestCase.runTest(self)
+        # As of Fedora 33 the --ntpservers and --nontp options are considered deprecated.
+
+        # Check using --ntpservers returns appropriate deprecation warning
+        with self.assertWarns(KickstartDeprecationWarning):
+            self.assert_parse("timezone --ntpservers foo,bar,baz")
+
+        # Check using --ntpservers returns appropriate deprecation warning
+        with self.assertWarns(KickstartDeprecationWarning):
+            self.assert_parse("timezone --nontp")
+
+class F40_TestCase(F33_TestCase):
+    command = "timezone"
+
+    def runTest(self):
+        F33_TestCase.runTest(self)
+
+        # deprecated
+        self.assert_deprecated("timezone", "--isUtc")
+        self.assert_deprecated("timezone", "--ntpservers")
+        self.assert_deprecated("timezone", "--nontp")
+
+class RHEL10_TestCase(F32_TestCase):
+    command = "timezone"
+
+    def runTest(self):
+        # removed
+        self.assert_removed("timezone", "--isUtc")
+        self.assert_removed("timezone", "--ntpservers")
+        self.assert_removed("timezone", "--nontp")
+
+        # Test failures
+        F32_TestCase.failures(self)
+
+        self.assert_parse("timezone --utc Europe/Bratislava",
+                          "timezone Europe/Bratislava --utc\n")
+        self.assert_parse("timezone --utc", "timezone --utc\n")
+        self.assert_parse("timezone Pacific", "timezone Pacific\n")
+
 if __name__ == "__main__":
     unittest.main()
