@@ -152,6 +152,18 @@ class StringToVersion_TestCase(CommandTest):
         # pass - F39
         self.assertEqual(stringToVersion("Fedora 39"), F39)
         self.assertEqual(stringToVersion("F39"), F39)
+        # pass - F40
+        self.assertEqual(stringToVersion("Fedora 40"), F40)
+        self.assertEqual(stringToVersion("F40"), F40)
+        # pass - F41
+        self.assertEqual(stringToVersion("Fedora 41"), F41)
+        self.assertEqual(stringToVersion("F41"), F41)
+        # pass - F42
+        self.assertEqual(stringToVersion("Fedora 42"), F42)
+        self.assertEqual(stringToVersion("F42"), F42)
+        # pass - F43
+        self.assertEqual(stringToVersion("Fedora 43"), F43)
+        self.assertEqual(stringToVersion("F43"), F43)
 
         # pass - RHEL3
         self.assertEqual(stringToVersion("Red Hat Enterprise Linux 3"), RHEL3)
@@ -211,6 +223,12 @@ class StringToVersion_TestCase(CommandTest):
             self.assertEqual(stringToVersion("Red Hat Enterprise Linux 9.%s" % MINOR), RHEL9)
         self.assertEqual(stringToVersion("RHEL9"), RHEL9)
 
+        # pass - RHEL10
+        self.assertEqual(stringToVersion("Red Hat Enterprise Linux 10"), RHEL10)
+        for MINOR in range(1,10):
+            self.assertEqual(stringToVersion("Red Hat Enterprise Linux 10.%s" % MINOR), RHEL10)
+        self.assertEqual(stringToVersion("RHEL10"), RHEL10)
+
 
 class VersionToString_TestCase(CommandTest):
     def runTest(self):
@@ -267,7 +285,11 @@ class VersionToString_TestCase(CommandTest):
         self.assertEqual(versionToString(F37, skipDevel=True), "F37")
         self.assertEqual(versionToString(F38, skipDevel=True), "F38")
         self.assertEqual(versionToString(F39, skipDevel=True), "F39")
-        self.assertEqual(versionToString(F39, skipDevel=False), "DEVEL")
+        self.assertEqual(versionToString(F40, skipDevel=True), "F40")
+        self.assertEqual(versionToString(F41, skipDevel=True), "F41")
+        self.assertEqual(versionToString(F42, skipDevel=True), "F42")
+        self.assertEqual(versionToString(F43, skipDevel=True), "F43")
+        self.assertEqual(versionToString(F43, skipDevel=False), "DEVEL")
         # RHEL series
         self.assertEqual(versionToString(RHEL3), "RHEL3")
         self.assertEqual(versionToString(RHEL4), "RHEL4")
@@ -276,6 +298,7 @@ class VersionToString_TestCase(CommandTest):
         self.assertEqual(versionToString(RHEL7), "RHEL7")
         self.assertEqual(versionToString(RHEL8), "RHEL8")
         self.assertEqual(versionToString(RHEL9), "RHEL9")
+        self.assertEqual(versionToString(RHEL10), "RHEL10")
 
         # fail
         self.assertRaises(KickstartVersionError, versionToString, 47)
@@ -293,6 +316,7 @@ class IsRHEL_TestCase(CommandTest):
         self.assertTrue(isRHEL(RHEL7))
         self.assertTrue(isRHEL(RHEL8))
         self.assertTrue(isRHEL(RHEL9))
+        self.assertTrue(isRHEL(RHEL10))
 
 class returnClassForVersion_TestCase(CommandTest):
     def runTest(self):
@@ -337,14 +361,14 @@ class versionFromFile_TestCase(CommandTest):
             os.close(fd)
             return name
 
-        # no version specified
+        # no version specified, defaults to DEFAULT_VERSION
         ks_cfg = '''
 # This is a sample kickstart file
 rootpw testing123
 cdrom
 '''
         ks_cfg = write_ks_cfg(ks_cfg)
-        self.assertEqual(versionFromFile(ks_cfg), DEVEL)
+        self.assertEqual(versionFromFile(ks_cfg), DEFAULT_VERSION)
         os.unlink(ks_cfg)
 
         # proper format ... DEVEL
@@ -369,7 +393,7 @@ cdrom
         self.assertEqual(versionFromFile(ks_cfg), RHEL3)
         os.unlink(ks_cfg)
 
-        # improper format ... fallback to DEVEL
+        # improper format ... fallback to DEFAULT_VERSION
         ks_cfg = '''
 # This is a sample kickstart file
 # version: FC3
@@ -377,7 +401,7 @@ rootpw testing123
 cdrom
 '''
         ks_cfg = write_ks_cfg(ks_cfg)
-        self.assertEqual(versionFromFile(ks_cfg), DEVEL)
+        self.assertEqual(versionFromFile(ks_cfg), DEFAULT_VERSION)
         os.unlink(ks_cfg)
 
         # unknown version specified ... raise exception
